@@ -1,5 +1,8 @@
-// Copyright (c) Mariana Meireles
+// Copyright (c) 2020, QuantStack, Mariana Meireles and ipycytoscape Contributors
+//
 // Distributed under the terms of the Modified BSD License.
+//
+// The full license is in the file LICENSE, distributed with this software.
 
 import { Application, IPlugin } from '@phosphor/application';
 
@@ -12,16 +15,16 @@ import { MODULE_NAME, MODULE_VERSION } from './version';
 const EXTENSION_ID = 'jupyter-cytoscape:plugin';
 
 /**
- * The example plugin.
+ * The ipycytoscape plugin.
  */
-const examplePlugin: IPlugin<Application<Widget>, void> = {
+const ipycytoscapePlugin: IPlugin<Application<Widget>, void> = {
   id: EXTENSION_ID,
   requires: [IJupyterWidgetRegistry as any],
   activate: activateWidgetExtension,
   autoStart: true,
 };
 
-export default examplePlugin;
+export default ipycytoscapePlugin;
 
 /**
  * Activate the widget extension.
@@ -33,8 +36,6 @@ function activateWidgetExtension(
   registry.registerWidget({
     name: MODULE_NAME,
     version: MODULE_VERSION,
-
-    exports: async () =>
-      await import(/* webpackChunkName: "jupyter-cytoscape" */ './widget'),
+    exports: () => import('./index'),
   });
 }
